# Copyright (C) 2023 Anthony Harrison
# SPDX-License-Identifier: Apache-2.0


class Vulnerability:
    def __init__(self, validation=None):
        self.vulnerability = {}
        if validation is not None and validation in ["openvex", "csaf", "cyclonedx"]:
            self.validation = validation
        else:
            self.validation = None

    def initialise(self):
        self.vulnerability = {}

    def set_name(self, name):
        self.vulnerability["product"] = name

    def set_release(self, release):
        self.vulnerability["release"] = release

    def set_id(self, id):
        self.vulnerability["id"] = id

    def set_description(self, description):
        self.vulnerability["description"] = description

    def set_comment(self, comment):
        self.vulnerability["comment"] = comment

    def validate_status(self, status):
        if self.validation == "openvex" and status in [
            "not_affected",
            "affected",
            "fixed",
            "under_investigation",
        ]:
            return True
        elif self.validation == "cyclonedx" and status in [
            "resolved",
            "resolved_with_pedigree",
            "exploitable",
            "in_triage",
            "false_positive",
            "not_affected",
        ]:
            return True
        elif self.validation == "csaf" and status in [
            "mitigation",
            "no_fix_planned",
            "none_available",
            "vendor_fix",
            "workaround",
        ]:
            return True
        return False

    def set_status(self, status):
        if self.validation is None:
            # No validation performed
            self.vulnerability["status"] = status.lower()
        elif self.validate_status(status.lower()):
            # Valid field according to specification
            self.vulnerability["status"] = status.lower()
        else:
            # Invalid field detected
            self.vulnerability["status"] = None

    def set_value(self, key, value):
        self.vulnerability[key] = value

    def get_vulnerability(self):
        return self.vulnerability

    def get_value(self, attribute):
        return self.vulnerability.get(attribute, None)

    def debug_vulnerability(self):
        print("OUTPUT:", self.vulnerability)

    def show_vulnerability(self):
        for key in self.vulnerability:
            print(f"{key}    : {self.vulnerability[key]}")

    def copy_vulnerability(self, vulnerability_info):
        for key in vulnerability_info:
            self.set_value(key, vulnerability_info[key])

    def get_name(self):
        return self.get_value("name")
